@@ -1,5 +1,5 @@
 ;;; emacspeak-midge.el --- Speech-enable MIDI editor
-;;; $Id: emacspeak-midge.el,v 17.0 2002/11/23 01:29:00 raman Exp $
+;;; $Id: emacspeak-midge.el,v 23.505 2005/11/25 16:30:50 raman Exp $
 ;;; $Author: raman $
 ;;; Description:  Emacspeak extension to speech-enable MIDGE
 ;;; Keywords: Emacspeak, MIDI 
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2002/11/23 01:29:00 $ |
-;;;  $Revision: 17.0 $ |
+;;; $Date: 2005/11/25 16:30:50 $ |
+;;;  $Revision: 23.505 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2002, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2004, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,15 +40,7 @@
 
 ;;{{{ required modules
 
-(eval-when-compile (require 'cl))
-(declaim  (optimize  (safety 0) (speed 3)))
-(require 'advice)
-(require 'emacspeak-speak)
-(require 'thingatpt)
-(require 'voice-lock)
-(require 'emacspeak-sounds)
-(require 'custom)
-
+(require 'emacspeak-preamble)
 ;;}}}
 ;;{{{  Introduction:
 
@@ -163,20 +155,6 @@
   (when (interactive-p)
     (emacspeak-auditory-icon 'task-done)))
 
-;;}}}
-;;{{{ voice lock
-
-(voice-lock-set-major-mode-keywords 'midge-mode
-				    'midge-voice-lock-keywords)
-
-(defvar midge-voice-lock-keywords nil
-  "Voice lock keywords for midge mode.")
-
-(setq midge-voice-lock-keywords
-      '(("^#[ \t].*$"  . voice-lock-comment-personality)
-	("[%@]\\([-+a-zA-Z0-9_*]+\\)" . voice-lock-function-name-personality)
-	("\\$[a-zA-Z0-9]+"  . voice-lock-variable-name-personality)))
-
 ;;}}}
 ;;{{{ midge-mode-hook
 (defgroup emacspeak-midge nil
