@@ -1,17 +1,19 @@
-#$Id: tts-lib.tcl,v 17.0 2002/11/23 01:29:09 raman Exp $
+#$Id: tts-lib.tcl,v 23.505 2005/11/25 16:30:52 raman Exp $
 # {{{ LCD Entry: 
-
+#x
 # LCD Archive Entry:
 # emacspeak| T. V. Raman |raman@cs.cornell.edu
 # A speech interface to Emacs |
-# $Date: 2002/11/23 01:29:09 $ |
-#  $Revision: 17.0 $ | 
+# $Date: 2005/11/25 16:30:52 $ |
+#  $Revision: 23.505 $ | 
 # Location undetermined
 #
 
 # }}}
-# {{{ Copyright:  
-#Copyright (C) 1995 -- 2002, T. V. Raman 
+# {{{ Copyright:
+
+#x
+#Copyright (C) 1995 -- 2003, T. V. Raman 
 #All Rights Reserved
 # Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 # All Rights Reserved. 
@@ -31,6 +33,7 @@
 # You should have received a copy of the GNU General Public License
 # along with GNU Emacs; see the file COPYING.  If not, write to
 # the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+#
 
 # }}}
 # {{{ sync state 
@@ -41,7 +44,7 @@ proc tts_sync_state {punct capitalize allcaps splitcaps rate} {
     tts_split_caps   $splitcaps
     tts_set_speech_rate  $rate
 } 
-
+# }}}
 # {{{ queue:
 
 #currently we use an inlined version of this test in speech_task
@@ -89,6 +92,7 @@ proc q {{element ""}} {
         return ""
     }
 }
+
 #queue a note 
 proc n {instrument note length {target 0} {step 5}} {
     global queue tts env
@@ -99,6 +103,14 @@ proc n {instrument note length {target 0} {step 5}} {
 }
 
 
+#queue a beep 
+proc b {{pitch 523} {length 100} {repeat 1} {duration 50}} {
+    global queue tts 
+    set queue($tts(q_tail)) [list b $pitch $length $repeat $duration]
+    incr tts(q_tail)
+    return ""
+}
+
 #queue a sound event
 
 proc a {sound} {
@@ -108,7 +120,6 @@ proc a {sound} {
     return ""
 }
 
-
 proc queue_rewind {} {
     global tts queue 
     if {$tts(q_head) == 0} {return ""}
@@ -117,7 +128,6 @@ proc queue_rewind {} {
     return $element
 }
 
-
 proc queue_retreat {{step 1}} {
     global tts queue 
     if {$tts(q_head) == 0} {return ""}
@@ -135,8 +145,6 @@ proc queue_advance {{step 1}} {
     return $element
 }
 
-
-
 proc queue_remove {} {
     global tts queue 
     set element  $queue($tts(q_head))
@@ -181,11 +189,11 @@ proc queue_restore {} {
 #play a sound over the server
 proc p {sound} {
     global tts
-    catch "exec $tts(play) $sound >& /dev/null &" errCode
+    catch "exec $tts(play) $sound >/dev/null  &" errCode
     speech_task
 }
 
-    # }}}
+# }}}
 # {{{notes: 
 
 #Simple notes player
@@ -244,6 +252,26 @@ proc notes_initialize {} {
     }
 }
 
+# }}}
+# {{{beep  
+
+#you need to have beep installed 
+
+proc beep_initialize {} {
+    global tts
+    if {[file executable /usr/bin/beep]} {
+        set tts(beep) 1
+    }
+}
+
+proc beep {{freq 523} {length 100} {repeat 1} {delay 10}} {
+    global tts
+    if {[info exists tts(beep)]
+        && $tts(beep) == 1}  {
+        exec beep -f $freq -l $length -r $repeat -d $delay &
+    }
+}
+
 # }}}
 # {{{self test 
 
@@ -376,7 +404,11 @@ proc tts_initialize {} {
     if {[info exists env(EMACSPEAK_PLAY_PROGRAM)] } {
         set tts(play)  $env(EMACSPEAK_PLAY_PROGRAM)
     } else {
-        set tts(play) "play"
+        if [file exists /usr/bin/aplay] {
+        set tts(play) "/usr/bin/aplay"
+        } else {
+            set tts(play) "play"
+        }
     }
     
     #optional debuggin output
@@ -390,8 +422,6 @@ proc tts_initialize {} {
     set tts(not_stopped) 1
 }
 
-# }}}
-
 # }}}
 # {{{ Emacs local variables  
 
